==> qtjambi-datavisualization-5.15.8-sources.jar: io/qt/datavis/QLogValue3DAxisFormatter.java <==
package io.qt.datavis;


/**
 * <p>Formatting rules for a logarithmic value axis</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html">QtDataVisualization::QLogValue3DAxisFormatter</a></p>
 */
public class QLogValue3DAxisFormatter extends io.qt.datavis.QValue3DAxisFormatter
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLogValue3DAxisFormatter.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#autoSubGrid-prop">QtDataVisualization::QLogValue3DAxisFormatter::autoSubGridChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="autoSubGrid")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> autoSubGridChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#base-prop">QtDataVisualization::QLogValue3DAxisFormatter::baseChanged(qreal)</a></p>
     */
    @io.qt.QtPropertyNotify(name="base")
    public final Signal1<@io.qt.QtPrimitiveType Double> baseChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#showEdgeLabels-prop">QtDataVisualization::QLogValue3DAxisFormatter::showEdgeLabelsChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="showEdgeLabels")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> showEdgeLabelsChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QLogValue3DAxisFormatter(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLogValue3DAxisFormatter() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#QLogValue3DAxisFormatter-1">QtDataVisualization::QLogValue3DAxisFormatter::QLogValue3DAxisFormatter(QObject*)</a></p>
     */
    public QLogValue3DAxisFormatter(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLogValue3DAxisFormatter instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#autoSubGrid-prop">QtDataVisualization::QLogValue3DAxisFormatter::autoSubGrid()const</a></p>
     */
    @io.qt.QtPropertyReader(name="autoSubGrid")
    @io.qt.QtUninvokable
    public final boolean autoSubGrid(){
        return autoSubGrid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean autoSubGrid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#base-prop">QtDataVisualization::QLogValue3DAxisFormatter::base()const</a></p>
     */
    @io.qt.QtPropertyReader(name="base")
    @io.qt.QtUninvokable
    public final double base(){
        return base_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native double base_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#autoSubGrid-prop">QtDataVisualization::QLogValue3DAxisFormatter::setAutoSubGrid(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="autoSubGrid")
    @io.qt.QtUninvokable
    public final void setAutoSubGrid(boolean enabled){
        setAutoSubGrid_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setAutoSubGrid_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#base-prop">QtDataVisualization::QLogValue3DAxisFormatter::setBase(qreal)</a></p>
     */
    @io.qt.QtPropertyWriter(name="base")
    @io.qt.QtUninvokable
    public final void setBase(double base){
        setBase_native_qtjambireal(QtJambi_LibraryUtilities.internal.nativeId(this), base);
    }
    
    @io.qt.QtUninvokable
    private native void setBase_native_qtjambireal(long __this__nativeId, double base);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#showEdgeLabels-prop">QtDataVisualization::QLogValue3DAxisFormatter::setShowEdgeLabels(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="showEdgeLabels")
    @io.qt.QtUninvokable
    public final void setShowEdgeLabels(boolean enabled){
        setShowEdgeLabels_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setShowEdgeLabels_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#showEdgeLabels-prop">QtDataVisualization::QLogValue3DAxisFormatter::showEdgeLabels()const</a></p>
     */
    @io.qt.QtPropertyReader(name="showEdgeLabels")
    @io.qt.QtUninvokable
    public final boolean showEdgeLabels(){
        return showEdgeLabels_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean showEdgeLabels_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#createNewInstance">QtDataVisualization::QValue3DAxisFormatter::createNewInstance()const</a></p>
     */
    @io.qt.QtUninvokable
    protected io.qt.datavis.QValue3DAxisFormatter createNewInstance(){
        return createNewInstance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QValue3DAxisFormatter createNewInstance_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#populateCopy">QtDataVisualization::QValue3DAxisFormatter::populateCopy(QtDataVisualization::QValue3DAxisFormatter&amp;)const</a></p>
     */
    @io.qt.QtUninvokable
    protected void populateCopy(io.qt.datavis.QValue3DAxisFormatter copy){
        populateCopy_native_ref_QtDataVisualization_QValue3DAxisFormatter_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(copy));
    }
    
    @io.qt.QtUninvokable
    private native void populateCopy_native_ref_QtDataVisualization_QValue3DAxisFormatter_constfct(long __this__nativeId, long copy);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#positionAt">QtDataVisualization::QValue3DAxisFormatter::positionAt(float)const</a></p>
     */
    @io.qt.QtUninvokable
    protected float positionAt(float value){
        return positionAt_native_float_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @io.qt.QtUninvokable
    private native float positionAt_native_float_constfct(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#recalculate">QtDataVisualization::QValue3DAxisFormatter::recalculate()</a></p>
     */
    @io.qt.QtUninvokable
    protected void recalculate(){
        recalculate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void recalculate_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#valueAt">QtDataVisualization::QValue3DAxisFormatter::valueAt(float)const</a></p>
     */
    @io.qt.QtUninvokable
    protected float valueAt(float position){
        return valueAt_native_float_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), position);
    }
    
    @io.qt.QtUninvokable
    private native float valueAt_native_float_constfct(long __this__nativeId, float position);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLogValue3DAxisFormatter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLogValue3DAxisFormatter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLogValue3DAxisFormatter instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-datavisualization-5.15.11-sources.jar: io/qt/datavis/QLogValue3DAxisFormatter.java <==
package io.qt.datavis;


/**
 * <p>Formatting rules for a logarithmic value axis</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html">QtDataVisualization::QLogValue3DAxisFormatter</a></p>
 */
public class QLogValue3DAxisFormatter extends io.qt.datavis.QValue3DAxisFormatter
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLogValue3DAxisFormatter.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#autoSubGrid-prop">QtDataVisualization::QLogValue3DAxisFormatter::autoSubGridChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="autoSubGrid")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> autoSubGridChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#base-prop">QtDataVisualization::QLogValue3DAxisFormatter::baseChanged(qreal)</a></p>
     */
    @io.qt.QtPropertyNotify(name="base")
    public final Signal1<@io.qt.QtPrimitiveType Double> baseChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#showEdgeLabels-prop">QtDataVisualization::QLogValue3DAxisFormatter::showEdgeLabelsChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="showEdgeLabels")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> showEdgeLabelsChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QLogValue3DAxisFormatter(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QLogValue3DAxisFormatter() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#QLogValue3DAxisFormatter-1">QtDataVisualization::QLogValue3DAxisFormatter::QLogValue3DAxisFormatter(QObject*)</a></p>
     */
    public QLogValue3DAxisFormatter(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLogValue3DAxisFormatter instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#autoSubGrid-prop">QtDataVisualization::QLogValue3DAxisFormatter::autoSubGrid()const</a></p>
     */
    @io.qt.QtPropertyReader(name="autoSubGrid")
    @io.qt.QtUninvokable
    public final boolean autoSubGrid(){
        return autoSubGrid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean autoSubGrid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#base-prop">QtDataVisualization::QLogValue3DAxisFormatter::base()const</a></p>
     */
    @io.qt.QtPropertyReader(name="base")
    @io.qt.QtUninvokable
    public final double base(){
        return base_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native double base_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#autoSubGrid-prop">QtDataVisualization::QLogValue3DAxisFormatter::setAutoSubGrid(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="autoSubGrid")
    @io.qt.QtUninvokable
    public final void setAutoSubGrid(boolean enabled){
        setAutoSubGrid_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setAutoSubGrid_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#base-prop">QtDataVisualization::QLogValue3DAxisFormatter::setBase(qreal)</a></p>
     */
    @io.qt.QtPropertyWriter(name="base")
    @io.qt.QtUninvokable
    public final void setBase(double base){
        setBase_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), base);
    }
    
    @io.qt.QtUninvokable
    private native void setBase_native_qreal(long __this__nativeId, double base);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#showEdgeLabels-prop">QtDataVisualization::QLogValue3DAxisFormatter::setShowEdgeLabels(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="showEdgeLabels")
    @io.qt.QtUninvokable
    public final void setShowEdgeLabels(boolean enabled){
        setShowEdgeLabels_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enabled);
    }
    
    @io.qt.QtUninvokable
    private native void setShowEdgeLabels_native_bool(long __this__nativeId, boolean enabled);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qlogvalue3daxisformatter.html#showEdgeLabels-prop">QtDataVisualization::QLogValue3DAxisFormatter::showEdgeLabels()const</a></p>
     */
    @io.qt.QtPropertyReader(name="showEdgeLabels")
    @io.qt.QtUninvokable
    public final boolean showEdgeLabels(){
        return showEdgeLabels_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean showEdgeLabels_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#createNewInstance">QtDataVisualization::QValue3DAxisFormatter::createNewInstance()const</a></p>
     */
    @io.qt.QtUninvokable
    protected io.qt.datavis.QValue3DAxisFormatter createNewInstance(){
        return createNewInstance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QValue3DAxisFormatter createNewInstance_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#populateCopy">QtDataVisualization::QValue3DAxisFormatter::populateCopy(QtDataVisualization::QValue3DAxisFormatter&amp;)const</a></p>
     */
    @io.qt.QtUninvokable
    protected void populateCopy(io.qt.datavis.QValue3DAxisFormatter copy){
        populateCopy_native_ref_QtDataVisualization_QValue3DAxisFormatter_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(copy));
    }
    
    @io.qt.QtUninvokable
    private native void populateCopy_native_ref_QtDataVisualization_QValue3DAxisFormatter_constfct(long __this__nativeId, long copy);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#positionAt">QtDataVisualization::QValue3DAxisFormatter::positionAt(float)const</a></p>
     */
    @io.qt.QtUninvokable
    protected float positionAt(float value){
        return positionAt_native_float_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @io.qt.QtUninvokable
    private native float positionAt_native_float_constfct(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#recalculate">QtDataVisualization::QValue3DAxisFormatter::recalculate()</a></p>
     */
    @io.qt.QtUninvokable
    protected void recalculate(){
        recalculate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void recalculate_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qvalue3daxisformatter.html#valueAt">QtDataVisualization::QValue3DAxisFormatter::valueAt(float)const</a></p>
     */
    @io.qt.QtUninvokable
    protected float valueAt(float position){
        return valueAt_native_float_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), position);
    }
    
    @io.qt.QtUninvokable
    private native float valueAt_native_float_constfct(long __this__nativeId, float position);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLogValue3DAxisFormatter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLogValue3DAxisFormatter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLogValue3DAxisFormatter instance, QDeclarativeConstructor constructor);
    
}
